//******************************************************************************
// The software reads the lux out of the OPT3001. 
// The INT pin must be connected to a LED+R to Vcc. 
// It will be turned on once the light intensity rises the Lux high limit  
// and it will be turned off once it will fall below the low limit. 
//
//
// Tested Platform: mini Controller Board PIC32
// Tested MCU: PIC32MX150F128D
// Tested Compiler: XC32 4.30
//******************************************************************************

#include "xc.h"

#define SYSTEM_CLOCK 32000000UL

#include "LTlib.h"

#include "HW_mini_Sensing_PIC_Board.h"

#include "LTlib_utilities.h"
#include "LTlib_utilities.c"

#include "module_IO.h"  
#include "module_IO.c" 

#include "module_UART.h"  
#include "module_UART.c" 

#include "module_I2C.h"
#include "module_I2C.c"

#include "LTlib_delay.h"
#include "LTlib_delay.c"

#include "OPT3001.h"
#include "OPT3001.c"

#define DEVICE_ADDRESS 0x44 //A0GND

int main (void){

    uint16_t data_readback = 0;
    uint8_t buffer[8];
    float lux = 0;
           
    IO_set_all_ports_as_inputs ();
    
    delay_set_quartz(16);
    
    //Set LED as output
    LED_1_DIR = SET_AS_OUTPUT;
    LED_2_DIR = SET_AS_OUTPUT;
    
    OPT_INT_DIR  = SET_AS_INPUT;
    
    LED_1 = LED_ON;
    LED_2 = LED_OFF;
    
    OPT3001_initialize(100);
    
    OPT3001_configuration (DEVICE_ADDRESS, OTP3001_CONF_AUTO_FULL_SCALE | OTP3001_CONF_CONVERSION_TIME_800ms |
                           OTP3001_CONF_MODE_CONTINUOUS_SAMPLING | OTP3001_CONF_INT_PIN_AS_COMPARATOR |
                            OTP3001_CONF_INT_POLARITY_ACTIVE_LOW | OTP3001_CONF_FAULT_COUNTER_1);
    
    OPT3001_set_high_limit (DEVICE_ADDRESS, 100);    
    OPT3001_set_low_limit (DEVICE_ADDRESS, 50);
    
    UART1_open (UART_BAUDRATE_19200);          
                        
    while (1){
        
        delay_ms (100);
        //Back space sent as clear monitor
        //RS232 Terminal must be set accordingly
        UART1_write_byte(8); 
        
        OPT3001_get_lux (DEVICE_ADDRESS, &lux);  
        LTlib_float_to_string (buffer, lux,2);
        UART1_write_message ("Lux : ");
        UART1_write_string(buffer);
        UART1_write_byte(13);
        
        OPT3001_get_register (DEVICE_ADDRESS, OPT3001_REG_DEVICE_ID, &data_readback);
        
        if (data_readback == OPT3001_DEVICE_ID) {
            LED_2 = LED_ON;
        } else {
             LED_2 = LED_OFF;
        }

        if (OPT_INT == 0x00) {
            LED_1 = 0x01;
        } else {
           LED_1 = 0x00;             
        }
        
    }
}   

