//******************************************************************************
// The Humidity and Temperature are monitored and the values are sent via UART. 
//
//
// Tested Platform: mini Controller Board PIC32
// Tested MCU: PIC32MX150F128D
// Tested Compiler: XC32 4.30
//******************************************************************************
#include "xc.h"

#define SYSTEM_CLOCK 32000000UL

#include "LTlib.h"

#include "HW_mini_Sensing_PIC_Board.h"

#include "LTlib_utilities.h"
#include "LTlib_utilities.c"

#include "module_IO.h"  
#include "module_IO.c" 

#include "module_UART.h"  
#include "module_UART.c" 

#include "module_I2C.h"
#include "module_I2C.c"

#include "LTlib_delay.h"
#include "LTlib_delay.c"

#include "HDC2080.h"
#include "HDC2080.c"

#define DEVICE_ADDRESS 0x40 //A0=GND

int main (void){

    uint8_t buffer[10];
    uint8_t counter = 0;
    
    float humidity = 0;
    float temperature = 0;
    uint16_t device_ID = 0;
    
    IO_set_all_ports_as_inputs ();
    delay_set_quartz(32);
 
    //Set LED as output
    LED_1_DIR = 0x00;
    LED_2_DIR = 0x00;
    
    LED_1 = LED_OFF;
    LED_2 = LED_OFF;

    HDC2080_initialize(DEVICE_ADDRESS, 400);  
    
    UART1_open (UART_BAUDRATE_19200);          
                        
    while (1){
        
        delay_ms (500);
        //Back space sent as clear monitor
        //RS232 Terminal must be set accordingly
        UART1_write_byte(8); 
        
        HDC2080_trigger_new_measure (DEVICE_ADDRESS);
        delay_ms (10);
  
        HDC2080_get_temperature (DEVICE_ADDRESS, &temperature); 
        LTlib_float_to_string (buffer, temperature,2);
        UART1_write_message ("Temperature : ");
        UART1_write_string(buffer);
        UART1_write_byte(13);
        
        HDC2080_get_humidity (DEVICE_ADDRESS, &humidity); 
        LTlib_float_to_string (buffer, humidity, 1);
        UART1_write_message ("Humidity : ");
        UART1_write_string(buffer);
        UART1_write_byte(13);
        
        HDC2080_get_device_ID (DEVICE_ADDRESS, &device_ID);
        
        if (device_ID == HDC2080_DEVICE_ID) {
            LED_2 = LED_ON;
        } else {
            LED_2 = LED_OFF;
        }

        LED_1 ^= 0x01;
        
    }
}   

