//******************************************************************************
// The software reads the acceleration and monitors it.
// The data ready and refresh is monitored via the interrupt pin.
// The data is sent out to the UART
//
// Tested Platform: mini Controller Board PIC32
// Tested MCU: PIC32MX150F128D
// Tested Compiler: XC32 4.30
//******************************************************************************

#include <xc.h>

#define SYSTEM_CLOCK 32000000UL
#include "LTlib.h"

#include "HW_mini_Sensing_PIC_Board.h"

#include "LTlib_delay.h"
#include "LTlib_delay.c"

#include "LTlib_utilities.h"
#include "LTlib_utilities.c"

#include "module_IO.h"
#include "module_IO.c"

#include "module_I2C.h"
#include "module_I2C.c"

#include "LSM6DSM.h"
#include "LSM6DSM.c"

#include "module_UART.h"  
#include "module_UART.c" 

#define DEVICE_ADDRESS 0x6A

int main (void) {
    
    uint8_t data = 0;
    uint8_t hex_string[6];
    
    uint8_t buffer[10];
    
    float Acc_X = 0;
    float Acc_Y = 0;
    float Acc_Z = 0;
        
    IO_set_all_ports_as_inputs();
    delay_set_quartz(32);
    
    LED_2_DIR  = SET_AS_OUTPUT;
        
    UART1_open (UART_BAUDRATE_19200);  
    
    LSM6DSM_initialize (DEVICE_ADDRESS, 400);
    LSM6DSM_set_full_scale (DEVICE_ADDRESS,LSM6DSM_ACCELEROMETER, LSM6DSM_ACC_FULLSCALE_8g);
    LSM6DSM_set_sampling_frequency (DEVICE_ADDRESS, LSM6DSM_ACCELEROMETER, LSM6DSM_ACC_SAMPLING_3330_HZ);
    
    LSM6DSM_get_device_ID (DEVICE_ADDRESS, &data); 
    LTlib_Hex8_to_string (hex_string, data);
    
    LSM6DSM_set_interrupt_pin_signals (DEVICE_ADDRESS, LSM6DSM_INT1_PIN, LSM6DSM_INT1_ACC_DATA_READY);
    
    //INT1 pin settings
    AG_INT_DIR = SET_AS_INPUT;
    
    while(1){   
        
        delay_ms (500);
        //Back space sent as clear monitor
        //RS232 Terminal must be set accordingly
        UART1_write_byte(8); 
        
        UART1_write_message("Device ID: 0x");
        UART1_write_string (hex_string);
        UART1_write_byte(13);
        UART1_write_byte(13);
        
        if (AG_INT == 0x01){
            
            LSM6DSM_get_acceleration(DEVICE_ADDRESS, &Acc_X, &Acc_Y, &Acc_Z);
            LTlib_float_to_string (buffer, Acc_X, 2);
            UART1_write_message("Acc. X: ");
            UART1_write_string(buffer);
            UART1_write_byte(13);
            UART1_write_byte(13);

            LTlib_float_to_string (buffer, Acc_Y, 2);
            UART1_write_message("Acc. Y: ");
            UART1_write_string(buffer);
            UART1_write_byte(13);
            UART1_write_byte(13);

            LTlib_float_to_string (buffer, Acc_Z, 2);
            UART1_write_message("Acc. Z: ");
            UART1_write_string(buffer);
            UART1_write_byte(13);
            UART1_write_byte(13);
        } else {
            UART1_write_message("No Acc. data ready...");
            UART1_write_byte(13);
            UART1_write_byte(13);
        }
        
        
        if (data == LSM6DSM_DEVICE_ID){
            LED_2 ^= 0x01;
            
        } else {
            LED_2 = 0x01;
        }
        
    }
}

